
--[[
================================================================================

  Sample 01 - The application's base

  This sample is a basic template to begin with your applications :)

  How to use:
    Copy this file in the "_bin" folder and rename this to "main.lua" 
    then initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

================================================================================
--]]

--[[
=================
Functions List

  - APP_RequiredVersion
  - APP_Init
  - APP_Run
  - APP_Quit
  - main

=================
--]]


 -- The attributes of the screen
 local APP_VIDEODRIVER = "directx" -- windib, directx, x11, svgalib
 local APP_AUDIODRIVER = "dsound"  -- waveout, dsound, alsa, arts, esd, dsp

 local APP_TITLE  = "SDLFW_app"
 local APP_WIDTH  = 512
 local APP_HEIGHT = 384
 local APP_BPP    = 32
 local APP_FLAGS  = SDL_HWSURFACE + SDL_DOUBLEBUF
 local APP_CURSOR = SDL_TRUE -- SDL_TRUE, SDL_FALSE


 local screen
 local event = SDLFW_GetGlobalEvent()
 local done  = false


--[[
================================================================================

  Callbacks

================================================================================
]]--


-- APP_RequiredVersion
--------------------------------------------------------------------------------
 local function APP_RequiredVersion()

  -- If you update to a better version, don't forget to update this too
  return SDLFW_RequiredVersion( 1, 6, 1 ) -- major, minor, patch

  -- return true -- If you want to avoid this requirement

 end


-- APP_Init
--------------------------------------------------------------------------------
 local function APP_Init()

  -- Sets the icon for the display window
  local image = SDL_LoadBMP( SDLFW_PATH .. "../samples/media/icon32.bmp" )
  if image ~= nil then
    SDL_SetColorKey ( image, SDL_SRCCOLORKEY, 
          SDL_MapRGB( image.format, 0x00, 0x00, 0x00 ) )
    SDLFW_WM_SetIcon( image )
    SDL_FreeSurface ( image )
  end

  -- Load a Windows BMP file
  image = SDL_LoadBMP( SDLFW_PATH .. "../samples/media/SDL_Logo.bmp" )
  if image ~= nil then
    SDL_BlitSurface( image, nil, screen, nil )
    SDL_Flip( screen )
    SDL_FreeSurface( image )
  end

  --- [ YOUR CODE HERE ] ---

 end


-- APP_Run
--------------------------------------------------------------------------------
 local function APP_Run()

  -- Check for messages
  if event.type == SDL_KEYDOWN then
    -- local sym = event.key.keysym.sym
    if event.key.keysym.sym == SDLK_ESCAPE or 
       event.key.keysym.sym == SDLK_F10 then
      done = true end

  end

  --- [ YOUR CODE HERE ] ---

 end


-- APP_Quit
--------------------------------------------------------------------------------
 local function APP_Quit()

  --- [ YOUR CODE HERE ] ---

 end


--[[
================================================================================

  Main

================================================================================
]]--


 local function main()

  -- Verify if the required version is equal or minor
  if APP_RequiredVersion() == false then
    print( "SDLFW version: " .. SDL_GetError() )
    return SDLFW_FAILURE
  end

  -- Load the SDL library
  if SDL_Init( SDL_INIT_EVERYTHING ) < 0 then
    print( "Couldn't initialize SDL: " .. SDL_GetError() )
    return SDLFW_FAILURE
  end

  -- Initialize the video subsystem, optionally specifying a video driver
  if SDL_VideoInit( APP_VIDEODRIVER, 0 ) ~= 0 then 
    print( "Error initializing " .. APP_VIDEODRIVER .. " video driver: " )
    print( " - " .. SDL_GetError() ) SDL_ClearError()
    SDL_VideoInit( nil, 0 )
  end

  -- Initialize the audio subsystem, optionally specifying a audio driver
  if SDL_AudioInit( APP_AUDIODRIVER ) ~= 0 then 
    print( "Error initializing " .. APP_AUDIODRIVER .. " audio driver: " )
    print( " - " .. SDL_GetError() ) SDL_ClearError()
    SDL_AudioInit( nil )
  end

  -- Sets the window tile and icon name
  SDL_WM_SetCaption( APP_TITLE, nil )
  -- Toggle whether or not the cursor is shown on the screen
  SDL_ShowCursor( APP_CURSOR )

  -- Check to see if a particular video mode is supported
  local bpp = SDL_VideoModeOK( APP_WIDTH, APP_HEIGHT, APP_BPP, APP_FLAGS )

  -- Create a new window
  screen = SDL_SetVideoMode( APP_WIDTH, APP_HEIGHT, bpp, APP_FLAGS )
  if screen == nil then
    print( "Unable to set the video mode: " .. SDL_GetError() )
    SDL_Quit() return SDLFW_FAILURE
  end

  APP_Init()

  -- Program main loop
  done = false
  while done == false do
    -- Message processing loop
    if SDL_PollEvent( event ) then
      -- Check for messages
      if event.type == SDL_QUIT then done = true end
    end

    APP_Run()

    -- Swaps screen buffers
    SDL_Flip( screen )
    -- Wait a specified number of milliseconds before returning
    SDL_Delay( 1 )
  end

  APP_Quit()

  -- Shuts down the audio subsystem
  SDL_AudioQuit()
  -- Shuts down the video subsystem
  SDL_VideoQuit()

  -- Make sure SDL cleans up before exit
  SDL_QuitSubSystem( SDL_INIT_EVERYTHING )
  SDL_Quit()

  return SDLFW_SUCCESS

 end

 if main() == SDLFW_SUCCESS then
  print( "Process terminated with status 0" )
 else
  print( "Process terminated with status 1" )
 end
