
--[[ Sample 04 - Optimized the surface loading and blitting

  This sample show how to optimized the surface loading and blitting.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - LoadImage
  - ApplySurface
  - main

--]]


 local SCREEN_WIDTH  = 640
 local SCREEN_HEIGHT = 480
 local SCREEN_BPP    = 32

 local function LoadImage( filename )

  -- Load the image
  local image = SDL_LoadBMP( filename )

  -- If nothing went wrong in loading the image
  if image ~= nil then

    -- Create an optimized image
    local optimized = SDL_DisplayFormat( image )

    -- If the image was optimized just fine
    if optimized ~= nil then

      -- Free the old image
      SDL_FreeSurface( image )

      image = optimized

    end
  end

  -- Return the optimized image
  return image

 end


 local function ApplySurface( source, destination, x, y  )

  -- Give the offsets to the rectangle
  local offset = SDLFW_CreateRect( x, y, 0, 0 )

  -- Blit the surface
  SDL_BlitSurface( source, nil, destination, offset )

 end


 local function main()

  if SDL_Init( SDL_INIT_VIDEO ) < 0 then exit( 1 ) end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    SDL_Quit() exit( 1 )
  end

  SDL_WM_SetCaption( "SDLFW - Optimized the surface loading and blitting", nil )

  -- Load the images
  local message    = LoadImage( SDLFW_PATH .. "../samples/media/hello.bmp" )
  local background = LoadImage( SDLFW_PATH .. "../samples/media/background.bmp" )

  -- Apply the background to the screen
  ApplySurface( background, screen,   0,   0 )
  ApplySurface( background, screen, 320,   0 )
  ApplySurface( background, screen,   0, 240 )
  ApplySurface( background, screen, 320, 240 )

  -- Apply the message to the screen
  ApplySurface( message, screen, 180, 140 )

  SDL_Flip( screen )

  SDL_Delay( 2000 );

  -- Free the loaded image
  SDL_FreeSurface( message )
  SDL_FreeSurface( background )

  SDL_Quit()

 end

 main()
