
--[[ Sample 05 - Event driven programming

  This sample show how to event driven programming.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - LoadImage
  - ApplySurface
  - main

--]]


 local SCREEN_WIDTH  = 640
 local SCREEN_HEIGHT = 480
 local SCREEN_BPP    = 32


 local function LoadImage( filename )

  local image = SDL_LoadBMP( filename )

  if image ~= nil then

    local optimized = SDL_DisplayFormat( image )

    if optimized ~= nil then

      SDL_FreeSurface( image )
      image = optimized

    end
  end

  return image

 end


 local function ApplySurface( source, destination, x, y  )

  local offset = SDLFW_CreateRect( x, y, 0, 0 )
  SDL_BlitSurface( source, nil, destination, offset )

 end


 local function main()

  if SDL_Init( SDL_INIT_VIDEO ) < 0 then exit( 1 ) end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    SDL_Quit() exit( 1 )
  end

  SDL_WM_SetCaption( "SDLFW - Event driven programming", nil )

  -- Load the image
  local image = LoadImage( SDLFW_PATH .. "../samples/media/x.bmp" )
  if image ~= nil then

    -- Apply the surface to the screen
    ApplySurface( image, screen, 0, 0 )

    SDL_FreeSurface( image )
  end

  SDL_Flip( screen )

  local event = SDLFW_GetGlobalEvent()

  -- While the user hasn't quit
  local done =  false
  while done == false do
    -- While there's an event to handle
    if SDL_PollEvent( event ) then
      -- If the user has X out the window
      if event.type == SDL_QUIT then done = true end
    end
  end

  SDL_Quit()

 end

 main()
