
--[[ Sample 06 - Color keying

  This sample show how to color keying.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - LoadImage
  - ApplySurface
  - main

--]]


 local SCREEN_WIDTH  = 640
 local SCREEN_HEIGHT = 480
 local SCREEN_BPP    = 32


 local function LoadImage( filename )

  local image = SDL_LoadBMP( filename )

  if image ~= nil then

    local optimized = SDL_DisplayFormat( image )

    if optimized ~= nil then

      SDL_FreeSurface( image )

      -- Map the color key
      local colorkey = SDL_MapRGB( optimized.format, 0, 0xFF, 0xFF )

      -- Set all pixels of color R 0, G 0xFF, B 0xFF to be transparent
      SDL_SetColorKey( optimized, SDL_SRCCOLORKEY, colorkey );

      image = optimized

    end
  end

  return image

 end


 local function ApplySurface( source, destination, x, y  )

  local offset = SDLFW_CreateRect( x, y, 0, 0 )
  SDL_BlitSurface( source, nil, destination, offset )

 end


 local function main()

  if SDL_Init( SDL_INIT_VIDEO ) < 0 then exit( 1 ) end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    SDL_Quit() exit( 1 )
  end

  SDL_WM_SetCaption( "SDLFW - Color keying", nil )

  -- Load the background image
  local background = LoadImage( SDLFW_PATH .. "../samples/media/background.bmp" )
  if background ~= nil then

    -- Apply the surface to the screen
    ApplySurface( background, screen, 0, 0 );

    -- Load the stick figure
    local foo = LoadImage( SDLFW_PATH .. "../samples/media/foo.bmp" )
    if foo ~= nil then

      -- Apply the surface to the screen
      ApplySurface( foo, screen, 240, 190 );

      SDL_FreeSurface( foo )
    end

    SDL_Flip( screen )

    SDL_FreeSurface( background )
  end

  local event = SDLFW_GetGlobalEvent()

  local done =  false
  while done == false do
    if SDL_PollEvent( event ) then
      if event.type == SDL_QUIT then done = true end
    end
  end

  SDL_Quit()

 end

 main()
