
--[[ Sample 07 - Clip blitting and sprite sheets

  This sample show how to clip blitting and sprite sheets.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - ApplySurface
  - main

--]]


 local SCREEN_WIDTH  = 640
 local SCREEN_HEIGHT = 480
 local SCREEN_BPP    = 32


 local function ApplySurface( source, destination, x, y, clip )

  local offset = SDLFW_CreateRect( x, y, 0, 0 )
  SDL_BlitSurface( source, clip, destination, offset )

 end


 local function main()

  if SDL_Init( SDL_INIT_VIDEO ) < 0 then exit( 1 ) end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    SDL_Quit() exit( 1 )
  end

  SDL_WM_SetCaption( "SDLFW - Clip blitting and sprite sheets", nil )

  -- Load image
  dots = SDL_LoadBMP( SDLFW_PATH .. "../samples/media/dots.bmp" )
  if dots == nil then
    SDL_Quit() exit( 1 )
  end

  local clip = {}

  -- Clip range for the top left
  clip[0] = SDLFW_CreateRect( 0, 0, 100, 100 )

  -- Clip range for the top right
  clip[1] = SDLFW_CreateRect( 100, 0, 100, 100 )

  -- Clip range for the bottom left
  clip[2] = SDLFW_CreateRect( 0, 100, 100, 100 )

  -- Clip range for the bottom right
  clip[3] = SDLFW_CreateRect( 100, 100, 100, 100 )

  -- Fill the screen white
  SDL_FillRect( screen, screen.clip_rect, SDL_MapRGB(screen.format, 0xFF, 0xFF, 0xFF) )

  -- Apply the sprites to the screen
  ApplySurface( dots, screen,   0,   0, clip[0] )
  ApplySurface( dots, screen, 540,   0, clip[1] )
  ApplySurface( dots, screen,   0, 380, clip[2] )
  ApplySurface( dots, screen, 540, 380, clip[3] )

  SDL_Flip( screen )

  local event = SDLFW_GetGlobalEvent()

  local done =  false
  while done == false do
    if SDL_PollEvent( event ) then
      if event.type == SDL_QUIT then done = true end
    end
  end

  SDL_FreeSurface( dots )
  SDL_Quit()

 end

 main()
