
--[[ Sample 09 - Mouse events

  This sample show how to mouse events.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - ApplySurface
  - main

--]]


 local SCREEN_WIDTH  = 640
 local SCREEN_HEIGHT = 480
 local SCREEN_BPP    = 32

 -- The button states in the sprite sheet
 local CLIP_MOUSEOVER = 0
 local CLIP_MOUSEOUT  = 1
 local CLIP_MOUSEDOWN = 2
 local CLIP_MOUSEUP   = 3

 -- The attributes of the button
 local box
 -- The part of the button sprite sheet that will be shown
 local clip
 -- The clip regions of the sprite sheet
 local clips = {}


 local event = SDLFW_GetGlobalEvent()


 local function ApplySurface( source, destination, x, y, clip )

  local offset = SDLFW_CreateRect( x, y, 0, 0 )
  SDL_BlitSurface( source, clip, destination, offset )

 end


 local function CreateButton( x, y, w, h )

  -- Set the button's attributes
  box = SDLFW_CreateRect( x, y, w, h )
  -- Set the default sprite
  clip = clips[ CLIP_MOUSEOUT ];

 end


 local function ButtonEvents()

  x = 0
  y = 0

  -- If the mouse moved
  if event.type == SDL_MOUSEMOTION then

    -- Get the mouse offsets
    x = event.motion.x
    y = event.motion.y

    -- If the mouse is over the button
    if ( x > box.x ) and ( x < box.x + box.w ) and ( y > box.y ) and ( y < box.y + box.h ) then

      -- Set the button sprite
      clip = clips[ CLIP_MOUSEOVER ]

    else

      -- Set the button sprite
      clip = clips[ CLIP_MOUSEOUT ]

    end
  end

  -- If a mouse button was pressed
  if event.type == SDL_MOUSEBUTTONDOWN then

    -- If the left mouse button was pressed
    if event.button.button == SDL_BUTTON_LEFT then

      -- Get the mouse offsets
      x = event.button.x
      y = event.button.y

      -- If the mouse is over the button
      if ( x > box.x ) and ( x < box.x + box.w ) and ( y > box.y ) and ( y < box.y + box.h ) then

        -- Set the button sprite
        clip = clips[ CLIP_MOUSEDOWN ]

      end
    end
  end

  -- If a mouse button was released
  if event.type == SDL_MOUSEBUTTONUP then

    -- If the left mouse button was released
    if event.button.button == SDL_BUTTON_LEFT then

      -- Get the mouse offsets
      x = event.button.x
      y = event.button.y

      -- If the mouse is over the button
      if ( x > box.x ) and ( x < box.x + box.w ) and ( y > box.y ) and ( y < box.y + box.h ) then

        -- Set the button sprite
        clip = clips[ CLIP_MOUSEUP ]

      end
    end
  end
 end


 local function main()

  if SDL_Init( SDL_INIT_VIDEO ) < 0 then exit( 1 ) end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    SDL_Quit() exit( 1 )
  end

  SDL_WM_SetCaption( "SDLFW - Mouse events", nil )

  -- Load image
  image = SDL_LoadBMP( SDLFW_PATH .. "../samples/media/button.bmp" )
  if image == nil then
    SDL_Quit() exit( 1 )
  end

  -- Clip the sprite sheet
  clips[CLIP_MOUSEOVER] = SDLFW_CreateRect(   0,   0, 320, 240 )
  clips[CLIP_MOUSEOUT]  = SDLFW_CreateRect( 320,   0, 320, 240 )
  clips[CLIP_MOUSEDOWN] = SDLFW_CreateRect(   0, 240, 320, 240 )
  clips[CLIP_MOUSEUP]   = SDLFW_CreateRect( 320, 240, 320, 240 )

  -- Make the button
  CreateButton( 170, 120, 320, 240 )

  local done =  false
  while done == false do
    if SDL_PollEvent( event ) then
      if event.type == SDL_QUIT then done = true end

      -- Handle button events
      ButtonEvents()

      -- Fill the screen white
      SDL_FillRect( screen, screen.clip_rect, SDL_MapRGB(screen.format, 0xFF, 0xFF, 0xFF) )

      -- Show the button
      ApplySurface( image, screen, box.x, box.y, clip )

      -- Finally, update the screen :)
      SDL_Flip( screen )

    end
  end

  SDL_FreeSurface( image )
  SDL_Quit()

 end

 main()
