
--[[ Sample 10 - Audio Playback

  This sample show how to load and playing a wave file into the memory.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - main

--]]


 local SCREEN_WIDTH  = 512
 local SCREEN_HEIGHT = 384
 local SCREEN_BPP    = 32


 local function main()

  -- Initializes the video and audio subsystems
  if SDL_Init( SDL_INIT_VIDEO + SDL_INIT_AUDIO ) < 0 then exit( 1 ) end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    SDL_Quit() exit( 1 )
  end

  SDL_WM_SetCaption( "SDLFW - Audio Playback", nil )

  local image = SDL_LoadBMP( SDLFW_PATH .. "../samples/media/SDL_Logo.bmp" )
  if image ~= nil then
    SDL_BlitSurface( image, nil, screen, nil )
    SDL_Flip( screen )
  end

  -- Load the wave file into memory
  local wave = SDLFW_LoadWAV( SDLFW_PATH .. "../samples/media/sample.wav" )
  if wave.id ~= 0 then

    -- Opens the audio device with the desired parameters
    if SDL_OpenAudio( wave.spec, nil ) == 0 then

      print( "Using audio driver: " .. SDLFW_AudioDriverName() )
      -- Pauses and unpauses the audio callback processing
      SDL_PauseAudio( 0 )
      -- Let the audio run
      SDLFW_AudioPlay( wave, true )

    end
  end

  local event = SDLFW_GetGlobalEvent()

  local done =  false
  while done == false do

    if SDL_PollEvent( event ) then
      if event.type == SDL_QUIT then done = true end
    end

    -- Is the wave file playing ?
    if SDLFW_IsAudioPlay( wave ) == false then done = true end

  end

  -- Shuts down audio processing and closes the audio device.
  SDL_CloseAudio()
  -- Frees previously opened WAV data
  SDLFW_FreeWAV( wave )

  SDL_Quit()

 end

 main()
