
--[[ Sample 03 - Load a Windows BMP file

  This sample show how to load a Windows BMP file into an SDL_Surface.

  How to use:
    1. Copy the "media" folder into the "_bin" folder.
    2. Copy this file into the "_bin" folder and rename this file to "main.lua".
    3. Initialize SDLFW.

  For more info:
    SDLFW.sf.net
    CorEduard@Programmer.net

--]]

--[[ Functions List 

  - main

--]]


 -- The attributes of the screen
 local SCREEN_WIDTH  = 512
 local SCREEN_HEIGHT = 384
 local SCREEN_BPP    = 32

 -- The surfaces
 local screen
 local background
 local message

 -- The font that's going to be used
 local font

 -- The event structure
 local event = SDLFW_GetGlobalEvent()

 -- The color of the font
 -- local textColor = SDLFW_CreateColorRGB( 255, 255, 255 );


 local function LoadImage( filename )

  -- Load the image
  local image = SDL_LoadBMP( filename )

  -- If nothing went wrong in loading the image
  if image ~= nil then

    -- Create an optimized image
    local optimized = SDL_DisplayFormat( image )

    -- If the image was optimized just fine
    if optimized ~= nil then

      -- Free the old image
      SDL_FreeSurface( image )

      image = optimized

    end
  end

  -- Return the optimized image
  return image

 end


 local function ApplySurface( source, destination, x, y  )

  -- Give the offsets to the rectangle
  local offset = SDLFW_CreateRect( x, y, 0, 0 )

  -- Blit the surface
  SDL_BlitSurface( source, nil, destination, offset )

 end


 local function main()

  if SDL_Init( SDL_INIT_EVERYTHING ) < 0 then exit( 1 ) end

  -- Initialize SDL_ttf
  if TTF_Init() < 0 then 
    SDL_Quit() return SDLFW_FAILURE
  end

  local screen = SDL_SetVideoMode( SCREEN_WIDTH, SCREEN_HEIGHT, SCREEN_BPP, SDL_SWSURFACE )
  if screen == nil then
    TTF_Quit()
    SDL_Quit() return SDLFW_FAILURE
  end

  SDL_WM_SetCaption( "SDLFW - TTF Test", nil )

  -- Load the images
  background = LoadImage( SDLFW_PATH .. "../samples/media/background.bmp" )

  -- Open the font
  font = TTF_OpenFont( SDLFW_PATH .. "../samples/media/deffont.ttf", 28 )
  if font == nil then
    print( "Break Point" )
  end

 -- The color of the font
 local textColor = SDLFW_CreateColor( 255, 255, 255 )

  -- Render the text
  message = TTF_RenderText_Solid( font, "Hello World!", textColor )

  -- Apply the images to the screen
  ApplySurface( background, screen, 0,   0 )
  ApplySurface( message, screen,    0, 150 )

  SDL_Flip( screen )

  -- While the user hasn't quit
  local done =  false
  while done == false do
    -- While there's an event to handle
    if SDL_PollEvent( event ) then
      -- If the user has X out the window
      if event.type == SDL_QUIT then done = true end
    end
  end

  -- Free the surfaces
  SDL_FreeSurface( background )
  SDL_FreeSurface( message )

  -- Close the font that was used
  TTF_CloseFont( font )

  -- Quit SDL_ttf
  TTF_Quit()
  SDL_Quit()

  return SDLFW_SUCCESS

 end

 if main() == SDLFW_SUCCESS then
  print( "Process terminated with status 0" )
 else
  print( "Process terminated with status 1" )
 end
